@@ -9,7 +9,6 @@
     /** @typedef {import("../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community").ColDef} ColDef */
     /** @typedef {import("../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community").ColGroupDef} ColGroupDef */
     /** @typedef {import("../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community").GridApi} GridApi */
-    /** @typedef {import("../../../../../../../../../../server/src/frontend/node_modules/ag-grid-community").ColumnApi} ColumnApi */
 
     angular.module('dataiku.charts')
         .factory('DisplayTotalsToolPanel', function() {
@@ -28,8 +27,6 @@
             class DisplayTotalsToolPanel {
 
                 constructor() {
-                    /** @type {ColumnApi} */
-                    this.columnApi = null;
                     /** @type {GridApi} */
                     this.gridApi = null;
                     /** @type {AgGridRow[]} */
@@ -124,14 +121,14 @@
                         if (this.hasGrandTotalRow && this.checkedState[GRAND_TOTALS_ROWS_ID]) {
                             rowData.push(this.grandTotalRowData);
                         }
-                        this.gridApi.setRowData(rowData);
+                        this.gridApi.setGridOption('rowData', rowData);
                     } else {
                         const rowData = [...this.rowData];
 
                         if (this.hasGrandTotalRow && this.checkedState[GRAND_TOTALS_ROWS_ID]) {
                             rowData.push(this.grandTotalRowData);
                         }
-                        this.gridApi.setRowData(rowData);
+                        this.gridApi.setGridOption('rowData', rowData);
                     }
                     this.pivotDisplayTotals.subTotals.rows = shouldDisplay;
                     this.setCheckboxState(TOTALS_ROWS_ID, shouldDisplay);
@@ -146,13 +143,13 @@
                     if (shouldDisplay) {
                         columnGroupShow = undefined;
                     }
-                    this.columnApi.getAllColumns()
+                    this.gridApi.getColumns()
                         .filter(col => col.getUserProvidedColDef().type === this.subtotalColumnType)
                         .forEach(col => {
                             col.setColDef({ ...col.getColDef(), columnGroupShow }, { colId: col.getColId() });
                         });
 
-                    this.gridApi.setColumnDefs(this.gridApi.getColumnDefs());
+                    this.gridApi.setGridOption('columnDefs', this.gridApi.getColumnDefs());
                     this.pivotDisplayTotals.subTotals.columns = shouldDisplay;
                     this.setCheckboxState(TOTALS_COLUMNS_ID, shouldDisplay);
                     if (!skipRowUpdate) {
@@ -188,9 +185,9 @@
                     const shouldDisplay = !this.checkedState[GRAND_TOTALS_COLUMNS_ID];
                     if (this.grandTotalColumnDef.children) {
                         // @ts-ignore
-                        this.grandTotalColumnDef.children.forEach(childCol => this.columnApi.setColumnVisible(childCol.field, shouldDisplay));
+                        this.grandTotalColumnDef.children.forEach(childCol => this.gridApi.setColumnsVisible([childCol.field], shouldDisplay));
                     }
-                    this.columnApi.setColumnVisible(this.grandTotalColumnDef.field, shouldDisplay);
+                    this.gridApi.setColumnsVisible([this.grandTotalColumnDef.field], shouldDisplay);
                     this.pivotDisplayTotals.grandTotal.column = shouldDisplay;
                     this.setCheckboxState(GRAND_TOTALS_COLUMNS_ID, shouldDisplay);
                 }
@@ -242,12 +239,11 @@
                     this.setParams(params);
                     this.eGui = document.createElement('div');
                     this.eGui.classList.add('expand-collapse-tool-panel');
-                    this.params = params.api;
                     const renderPanel = () => {
                         this.renderTemplate();
                         this.setToolPanelButtonIcon();
                     };
-                    params.api.addEventListener('gridReady', renderPanel);
+                    this.gridApi.addEventListener('gridReady', renderPanel);
                 }
                 /**
                  * @param {DisplayTotalsToolPanelParams} params
@@ -269,7 +265,6 @@
                     this.subtotalColumnType = params.subtotalColumnType;
                     this.$rootElement = params.$rootElement;
                     this.gridApi = params.api;
-                    this.columnApi = params.columnApi;
                     this.rowData = params.rowData;
                     this.subtotalRowData = params.subtotalRowData;
                     this.grandTotalRowData = params.grandTotalRowData;
