@@ -39,6 +39,7 @@
             numberOfCellsMatchingCustomHeight: false,
             numberOfCellsMatchingCustomWidth: false,
             addExtraGridSpaceBelow: true,
+            autoStackUp: false,
             offsetHeight: 0,
             offsetWidth: 0
         },
@@ -81,6 +82,25 @@
             this.reflow();
         },
 
+        toggleAutoStackUp: function(autoStackUp) {
+            this._createGridSnapshot();
+            this.gridList.toggleGapMode(!autoStackUp);
+            this.options.autoStackUp = autoStackUp;
+            this._updateGridSnapshot();
+            this.reflow();
+        },
+
+        stackItemsUp: function() {
+            this._createGridSnapshot();
+            this.gridList.fillDirectionalGaps();
+            this._updateGridSnapshot();
+            this.reflow();
+        },
+
+        canStackItemsUp: function() {
+            return this.gridList.hasDirectionalGaps();
+        },
+
         captureItemSizeAndPositionSnapshot: function() {
             this.gridList.captureItemSizeAndPositionSnapshot();
         },
@@ -644,7 +664,8 @@
              */
             this.gridList = new GridList(items, {
                 lanes: this.options.lanes,
-                direction: this.options.direction
+                direction: this.options.direction,
+                allowDirectionalGaps: !this.options.autoStackUp
             });
         },
 
@@ -763,8 +784,15 @@
                  */
                 item = this._getItemByElement(ui.helper);
                 this.gridList.moveItemToPosition(item, xyCoordinates);
-                // Visually update item positions and highlight shape
+
+                // Visually update item positions
                 this._applyPositionToItems();
+                /*
+                 * Collision solving algorithm might have change item reference when calling `moveItemToPosition`,
+                 * and we need to get its updated position that might have been changed by packItemsOverGridDirection.
+                 */
+                item = this._getItemByElement(ui.helper);
+                // Highlight shape
                 this._highlightPositionForItem(item);
             }
         },
@@ -1118,4 +1146,8 @@
         });
         return instance;
     };
+
+    $.fn.getGridListInstance = function() {
+        return this.first().data('_gridList');
+    };
 });
